package de.twomartens.oparlservice.actuator;

import de.twomartens.oparlservice.entity.dto.System;
import de.twomartens.oparlservice.interceptors.RequestTypeInterceptor;
import de.twomartens.oparlservice.interceptors.TraceIdInterceptor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.actuate.health.HealthIndicator;
import org.springframework.boot.autoconfigure.web.ServerProperties;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;

import java.util.Optional;

/**
 * A Health check which checks if the rest services are working.]
 */
@Slf4j
@Component
public class RestHealthCheck extends AbstractHealthCheck implements HealthIndicator {

  private final RestTemplate restTemplate;

  public RestHealthCheck(ServerProperties serverProperties,
      TraceIdInterceptor traceIdInterceptor,
      RequestTypeInterceptor requestTypeInterceptor,
      RestTemplate restTemplate) {
    super(Optional.ofNullable(serverProperties.getPort()).orElse(8080),
        traceIdInterceptor, requestTypeInterceptor);
    this.restTemplate = restTemplate;
  }

  @Override
  boolean isEndpointAvailable() {
    try {
      ResponseEntity<System> result = restTemplate.getForEntity(getEndpoint(), System.class);
      System body = result.getBody();
      if (body == null) {
        return false;
      }
      return !body.getId().isEmpty();
    } catch (RestClientException e) {
      return false;
    }
  }

  @Override
  String getMethodName() {
    return "oparl-service-rest";
  }

  String mkEndpoint() {
    return String.format("http://%s:%d/v1.1/", getHost(), getPort());
  }
}
