package de.twomartens.oparlservice.entity.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;

import java.time.LocalDate;
import java.time.ZonedDateTime;

@Builder
@Getter
@ToString
@EqualsAndHashCode
@AllArgsConstructor(access = AccessLevel.PRIVATE)
@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class Membership {
    @NonNull
    @Schema(required = true, description = "The unique identifier of the object")
    private final String id;

    @NonNull
    @Schema(required = true, description = "Namespace URL to the object type schema")
    private final String type;

    @NonNull
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(required = true, description = "Date and time of the creation of the object")
    private final ZonedDateTime created;

    @NonNull
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(required = true, description = "Date and time of the last update of the object")
    private final ZonedDateTime modified;

    @Schema(description = "URL to the license")
    private String license;

    @Schema(description = "Categorization of the object")
    private String keyword;

    @Schema(description = "URL of a website that presents the object in the browser")
    private String web;

    @Schema(description = "True, if the object was deleted")
    private final boolean deleted;

    @Schema(description = "URL to the person related to this membership")
    private final String person;

    @Schema(description = "URL to the organization related to this membership")
    private final String organization;

    @Schema(description = "role of the person for the organization")
    private final String role;

    @Schema(description = "True if the person has a voting right in the organization")
    private final boolean votingRight;

    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(description = "first day of the membership")
    private final LocalDate startDate;

    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(description = "last day of the membership")
    private final LocalDate endDate;

    @Schema(description = "URL to the organization for which the person is member in the organization")
    private final String onBehalfOf;
}
