package de.twomartens.oparlservice.entity.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;

import java.time.ZonedDateTime;
import java.util.List;

@Builder
@Getter
@ToString
@EqualsAndHashCode
@AllArgsConstructor(access = AccessLevel.PRIVATE)
@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class System {
    @NonNull
    @Schema(required = true, description = "The unique identifier of the object")
    private final String id;

    @NonNull
    @Schema(required = true, description = "Namespace URL to the object type schema")
    private final String type;

    @NonNull
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(required = true, description = "Date and time of the creation of the object")
    private final ZonedDateTime created;

    @NonNull
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @Schema(required = true, description = "Date and time of the last update of the object")
    private final ZonedDateTime modified;

    @Schema(description = "URL to the license")
    private String license;

    @Schema(description = "URL of a website that presents the object in the browser")
    private String web;

    @Schema(description = "True, if the object was deleted")
    private final boolean deleted;

    @NonNull
    @Schema(required = true, description = "URL to the OParl specification supported by this service")
    private final String oparlVersion;

    @Schema(description = "Contains a list of URLs to System objects supporting another Oparl version")
    private final List<String> otherOparlVersions;

    @NonNull
    @Schema(required = true, description = "URL to the list of all bodies existing in this system")
    private final String body;

    @Schema(description = "User friendly name for this system")
    private final String name;

    @Schema(description = "E-Mail-Address for requests related to the OParl-API")
    private final String contactEmail;

    @Schema(description = "Name of the contact person who can be reached by contactEmail")
    private final String contactName;

    @Schema(description = "URL of the website of the parliamentary information system")
    private final String website;

    @Schema(description = "URL to the website of the software creator of the OParl server software")
    private final String vendor;

    @Schema(description = "URL to information about the OParl server software utilized by this system")
    private final String product;
}
